@@ -1,13 +1,13 @@
 """
 API for :ref:`custom-comment-app-api`
 """
-from django.contrib.comments import Comment
 from fluent_comments import appsettings
+from fluent_comments.models import FluentComment
 from fluent_comments.forms import FluentCommentForm
 
 
-# following PEP 386
-__version__ = "0.9.2"
+# following PEP 440
+__version__ = "1.0.4"
 
 
 if appsettings.USE_THREADEDCOMMENTS:
@@ -23,7 +23,8 @@ def get_model():
     if appsettings.USE_THREADEDCOMMENTS:
         return ThreadedComment
     else:
-        return Comment
+        # Our proxy model that performs select_related('user') for the comments
+        return FluentComment
 
 
 def get_form():
