@@ -1,11 +1,12 @@
+import sys
 from django.conf import settings
 from django.contrib import admin
-from django.contrib import comments
 from django.contrib.admin.widgets import AdminTextInputWidget
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.html import escape
 from django.utils.translation import ugettext_lazy as _
 from fluent_comments import appsettings
+from .compat import get_model as get_comments_model, BASE_APP
 
 
 # Ensure the admin app is loaded,
@@ -17,7 +18,16 @@ if appsettings.USE_THREADEDCOMMENTS:
 
     from threadedcomments.admin import ThreadedCommentsAdmin as CommentsAdminBase
 else:
-    from django.contrib.comments.admin import CommentsAdmin as CommentsAdminBase
+    # This code is not in the .compat module to avoid admin imports in all other code.
+    # The admin import usually starts a model registration too, hence keep these imports here.
+    if BASE_APP == 'django.contrib.comments':
+        # Django 1.7 and below
+        from django.contrib.comments.admin import CommentsAdmin as CommentsAdminBase
+    elif BASE_APP == 'django_comments':
+        # Django 1.8 and up
+        from django_comments.admin import CommentsAdmin as CommentsAdminBase
+    else:
+        raise NotImplementedError()
 
 
 class FluentCommentsAdmin(CommentsAdminBase):
@@ -28,7 +38,7 @@ class FluentCommentsAdmin(CommentsAdminBase):
     Adding comments can happen at the frontend instead.
 
     The fieldsets are more logically organized, and the generic relation is a readonly field instead of a massive pulldown + textarea.
-    The class supports both the standard ``django.contrib.comments`` and the ``threadedcomments`` applications.
+    The class supports both the standard ``django_comments`` and the ``threadedcomments`` applications.
     """
 
     fieldsets = [
@@ -53,12 +63,15 @@ class FluentCommentsAdmin(CommentsAdminBase):
         raw_id_fields = ('parent',)
 
 
-    def queryset(self, request):
-        return super(FluentCommentsAdmin, self).queryset(request).select_related('user')
+    def get_queryset(self, request):
+        return super(FluentCommentsAdmin, self).get_queryset(request).select_related('user')
 
     def object_link(self, comment):
         object = comment.content_object
-        title = unicode(object)
+        if sys.version_info[0] >= 3:
+            title = str(object)
+        else:
+            title = unicode(object)
         return u'<a href="{0}">{1}</a>'.format(escape(object.get_absolute_url()), escape(title))
 
     object_link.short_description = _("Page")
@@ -69,7 +82,10 @@ class FluentCommentsAdmin(CommentsAdminBase):
             return comment.user_name
         elif comment.user_id:
             # Can't do much else here, User model might be custom.
-            return unicode(comment.user)
+            if sys.version_info[0] >= 3:
+                return str(comment.user)
+            else:
+                return unicode(comment.user)
         else:
             return None
 
@@ -86,7 +102,7 @@ class FluentCommentsAdmin(CommentsAdminBase):
 
 # Replace the old admin screen.
 if appsettings.FLUENT_COMMENTS_REPLACE_ADMIN:
-    CommentModel = comments.get_model()
+    CommentModel = get_comments_model()
     try:
         admin.site.unregister(CommentModel)
     except admin.sites.NotRegistered as e:
