@@ -1,12 +1,36 @@
+import django
 from django.conf import settings
-from django.contrib import comments
 from django.contrib.contenttypes.generic import GenericRelation
 from django.contrib.sites.models import get_current_site
 from django.core.mail import send_mail
 from django.dispatch import receiver
-from django.contrib.comments import signals
-from django.shortcuts import render
+from django.template import RequestContext
+from django.template.loader import render_to_string
 from fluent_comments import appsettings
+from .compat import CommentManager, Comment, signals, get_model as get_comments_model
+
+
+class FluentCommentManager(CommentManager):
+    """
+    Manager to optimize SQL queries for comments.
+    """
+    def get_queryset(self):
+        return super(CommentManager, self).get_queryset().select_related('user')
+
+    if django.VERSION >= (1,7):
+        # This is a workaround to let django-contrib-comments 1.5 work.
+        def get_query_set(self):
+            return self.get_queryset()
+
+
+class FluentComment(Comment):
+    """
+    Proxy model to make sure that a ``select_related()`` is performed on the ``user`` field.
+    """
+    objects = FluentCommentManager()
+
+    class Meta:
+        proxy = True
 
 
 @receiver(signals.comment_was_posted)
@@ -14,7 +38,7 @@ def on_comment_posted(sender, comment, request, **kwargs):
     """
     Send email notification of a new comment to site staff when email notifications have been requested.
     """
-    # This code is copied from django.contrib.comments.moderation.
+    # This code is copied from django_comments.moderation.
     # That code doesn't offer a RequestContext, which makes it really
     # hard to generate proper URL's with FQDN in the email
     #
@@ -27,14 +51,14 @@ def on_comment_posted(sender, comment, request, **kwargs):
     site = get_current_site(request)
     content_object = comment.content_object
 
-    subject = '[{0}] New comment posted on "{1}"'.format(site.name, content_object)
+    subject = u'[{0}] New comment posted on "{1}"'.format(site.name, content_object)
     context = {
         'site': site,
         'comment': comment,
         'content_object': content_object
     }
 
-    message = render(request, "comments/comment_notification_email.txt", context)
+    message = render_to_string("comments/comment_notification_email.txt", context, RequestContext(request))
     send_mail(subject, message, settings.DEFAULT_FROM_EMAIL, recipient_list, fail_silently=True)
 
 
@@ -42,7 +66,7 @@ def get_comments_for_model(content_object, include_moderated=False):
     """
     Return the QuerySet with all comments for a given model.
     """
-    qs = comments.get_model().objects.for_model(content_object)
+    qs = get_comments_model().objects.for_model(content_object)
 
     if not include_moderated:
         qs = qs.filter(is_public=True, is_removed=False)
@@ -62,7 +86,7 @@ class CommentsRelation(GenericRelation):
     """
     def __init__(self, *args, **kwargs):
         super(CommentsRelation, self).__init__(
-            to=comments.get_model(),
+            to=get_comments_model(),
             content_type_field='content_type',
             object_id_field='object_pk',
             **kwargs
