@@ -1,15 +1,30 @@
-from django.contrib.comments.moderation import CommentModerator, moderator
+import warnings
 from django.contrib.sites.models import get_current_site
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.encoding import smart_str
-from akismet import Akismet
 from fluent_comments import appsettings
+from .compat import BASE_APP
+
+if BASE_APP == 'django.contrib.comments':
+    from django.contrib.comments.moderation import moderator, CommentModerator
+elif BASE_APP == 'django_comments':
+    from django_comments.moderation import moderator, CommentModerator
+else:
+    raise NotImplementedError()
 
 try:
     from urllib.parse import urljoin  # Python 3
 except ImportError:
     from urlparse import urljoin  # Python 2
 
+# Optional dependency (for lacking Python 3 support)
+try:
+    from akismet import Akismet
+except ImportError:
+    Akismet = None
+    if appsettings.FLUENT_CONTENTS_USE_AKISMET:
+        warnings.warn("No `akismet` package has been installed, disabling Akismet checks for django-fluent-comments.", RuntimeWarning)
+
 
 # Akismet code originally based on django-comments-spamfighter.
 
@@ -33,7 +48,7 @@ class FluentCommentsModerator(CommentModerator):
     close_after = appsettings.FLUENT_COMMENTS_CLOSE_AFTER_DAYS
     moderate_after = appsettings.FLUENT_COMMENTS_MODERATE_AFTER_DAYS
     email_notification = False   # Using signals instead
-    akismet_check = appsettings.FLUENT_CONTENTS_USE_AKISMET
+    akismet_check = appsettings.FLUENT_CONTENTS_USE_AKISMET and Akismet is not None
     akismet_check_action = appsettings.FLUENT_COMMENTS_AKISMET_ACTION
 
 
@@ -162,7 +177,7 @@ def get_model_moderator(model):
     :param model: The Django model registered with :func:`moderate_model`
     :type model: :class:`~django.db.models.Model`
     :return: The moderator class which holds the moderation policies.
-    :rtype: :class:`~django.contrib.comments.moderation.CommentModerator`
+    :rtype: :class:`~django_comments.moderation.CommentModerator`
     """
     try:
         return moderator._registry[model]
