@@ -3,14 +3,16 @@ from django.db import models
 from django.http import HttpResponse, HttpResponseBadRequest
 from django.template.loader import render_to_string
 from django.template import RequestContext
-from django.contrib import comments
-from django.contrib.comments import signals
-from django.contrib.comments.views.comments import CommentPostBadRequest
 from django.utils.html import escape
 from django.views.decorators.csrf import csrf_protect
 from django.views.decorators.http import require_POST
+from .compat import get_form as get_comments_form, signals, CommentPostBadRequest
 from fluent_comments import appsettings
 import json
+import sys
+
+if sys.version_info[0] >= 3:
+    long = int
 
 
 @csrf_protect
@@ -22,7 +24,7 @@ def post_comment_ajax(request, using=None):
     if not request.is_ajax():
         return HttpResponseBadRequest("Expecting Ajax call")
 
-    # This is copied from django.contrib.comments.
+    # This is copied from django_comments.
     # Basically that view does too much, and doesn't offer a hook to change the rendering.
     # The request object is not passed to next_redirect for example.
     #
@@ -44,8 +46,11 @@ def post_comment_ajax(request, using=None):
     if ctype is None or object_pk is None:
         return CommentPostBadRequest("Missing content_type or object_pk field.")
     try:
+        object_pk = long(object_pk)
         model = models.get_model(*ctype.split(".", 1))
         target = model._default_manager.using(using).get(pk=object_pk)
+    except ValueError:
+        return CommentPostBadRequest("Invalid object_pk value: {0}".format(escape(object_pk)))
     except TypeError:
         return CommentPostBadRequest("Invalid content_type value: {0}".format(escape(ctype)))
     except AttributeError:
@@ -59,18 +64,18 @@ def post_comment_ajax(request, using=None):
     preview = "preview" in data
 
     # Construct the comment form
-    form = comments.get_form()(target, data=data)
+    form = get_comments_form()(target, data=data)
 
     # Check security information
     if form.security_errors():
-        return CommentPostBadRequest("The comment form failed security verification: {0}".format)
+        return CommentPostBadRequest("The comment form failed security verification: {0}".format(form.security_errors()))
 
     # If there are errors or if we requested a preview show the comment
     if preview:
         comment = form.get_comment_object() if not form.errors else None
-        return _ajax_result(request, form, "preview", comment)
+        return _ajax_result(request, form, "preview", comment, object_id=object_pk)
     if form.errors:
-        return _ajax_result(request, form, "post")
+        return _ajax_result(request, form, "post", object_id=object_pk)
 
 
     # Otherwise create the comment
@@ -98,10 +103,10 @@ def post_comment_ajax(request, using=None):
         request = request
     )
 
-    return _ajax_result(request, form, "post", comment)
+    return _ajax_result(request, form, "post", comment, object_id=object_pk)
 
 
-def _ajax_result(request, form, action, comment=None):
+def _ajax_result(request, form, action, comment=None, object_id=None):
     # Based on django-ajaxcomments, BSD licensed.
     # Copyright (c) 2009 Brandon Konkle and individual contributors.
     #
@@ -121,6 +126,7 @@ def _ajax_result(request, form, action, comment=None):
         'success': success,
         'action': action,
         'errors': json_errors,
+        'object_id': object_id,
         'use_threadedcomments': bool(appsettings.USE_THREADEDCOMMENTS),
     }
 
@@ -143,7 +149,7 @@ def _ajax_result(request, form, action, comment=None):
             json_return['parent_id'] = comment.parent_id
 
     json_response = json.dumps(json_return)
-    return HttpResponse(json_response, mimetype="application/json")
+    return HttpResponse(json_response, content_type="application/json")
 
 
 def _render_errors(field):
